1.6.2
=====

Issue #1: Fix WordSet on Python 2.

1.6
===

Drop dependency on jaraco.context (and its dependencies).

1.5
===

Move hosting to github.

Add missing namespace package declaration in distribution.

1.4
===

Add Stripper class.

1.3
===

Add SeparatedValues class.

1.0
===

Initial implementation adopted from jaraco.util.string 10.8.
